This project is under development by intechlligent
you can watch our other videos on youtube
this project after completion will be capable of sending text messages from whatsapp facebook twitter instagram gmail and more at any time and on its own.